:orphan:

.. _sql-storage:

SQL storage
===========

Postgres DB schema
------------------

.. _swh-storage-db-schema:
.. figure:: ../sql/doc/sql/db-schema.svg
   :width: 1024px
   :align: center

   Postgres DB schema of high-level Software Heritage storage (click to zoom).
